==> devpulse_cli-0.1.3.tar.gz: devpulse_cli-0.1.3/devpulse/commands/report.py <==
import typer

app = typer.Typer(help="Enhanced productivity reports")


@app.command()
def daily(
    date: str = typer.Option("today", "--date", "-d", help="Report date (today, yesterday, YYYY-MM-DD)"),
    detailed: bool = typer.Option(False, "--detailed", help="Show detailed breakdown")
):
    """Generate daily productivity report."""
    typer.echo(f"📊 Daily Report: {date}")
    typer.echo("Time tracked: 0h 0m")
    typer.echo("Tasks completed: 0")
    if detailed:
        typer.echo("\n📋 Breakdown:")
        typer.echo("- Morning: 0h")
        typer.echo("- Afternoon: 0h")
        typer.echo("- Evening: 0h")


@app.command()
def weekly(export: str = typer.Option(None, "--export", "-e", help="Export format (pdf, html, xlsx)")):
    """Generate weekly productivity report."""
    typer.echo("📊 Weekly Report")
    typer.echo("Total time: 0h 0m")
    typer.echo("Most productive day: N/A")
    typer.echo("Average daily: 0h")
    if export:
        typer.echo(f"\n✅ Report exported as {export}")


@app.command()
def monthly(format: str = typer.Option("console", "--format", "-f", help="Format (console, pdf, html)")):
    """Generate monthly productivity report."""
    typer.echo("📊 Monthly Report")
    typer.echo("Total tracked: 0h 0m")
    typer.echo("Top project: N/A")
    typer.echo("Productivity trend: N/A")


@app.command()
def comparison(
    period1: str = typer.Argument("last-month", help="First period"),
    period2: str = typer.Argument("this-month", help="Second period")
):
    """Compare productivity between periods."""
    typer.echo(f"📊 Comparison: {period1} vs {period2}")
    typer.echo("Change: No data")


@app.command()
def summary():
    """Quick productivity summary."""
    typer.echo("📈 Productivity Summary:")
    typer.echo("Today: 0h tracked")
    typer.echo("This week: 0h tracked")
    typer.echo("This month: 0h tracked")


@app.command()
def insights():
    """AI insights on productivity."""
    typer.echo("💡 Productivity Insights:")
    typer.echo("- No data available for analysis")
    typer.echo("- Start tracking to see insights")

==> devpulse_cli-0.2.0.tar.gz: devpulse_cli-0.2.0/devpulse/commands/report.py <==
import typer

app = typer.Typer(help="Enhanced productivity reports")


@app.command()
def daily(
    date: str = typer.Option("today", "--date", "-d", help="Report date (today, yesterday, YYYY-MM-DD)"),
    detailed: bool = typer.Option(False, "--detailed", help="Show detailed breakdown")
):
    """Generate daily productivity report."""
    typer.echo(f"📊 Daily Report: {date}")
    typer.echo("Time tracked: 0h 0m")
    typer.echo("Tasks completed: 0")
    if detailed:
        typer.echo("\n[*] Breakdown:")
        typer.echo("- Morning: 0h")
        typer.echo("- Afternoon: 0h")
        typer.echo("- Evening: 0h")


@app.command()
def weekly(export: str = typer.Option(None, "--export", "-e", help="Export format (pdf, html, xlsx)")):
    """Generate weekly productivity report."""
    typer.echo("📊 Weekly Report")
    typer.echo("Total time: 0h 0m")
    typer.echo("Most productive day: N/A")
    typer.echo("Average daily: 0h")
    if export:
        typer.echo(f"\n[OK] Report exported as {export}")


@app.command()
def monthly(format: str = typer.Option("console", "--format", "-f", help="Format (console, pdf, html)")):
    """Generate monthly productivity report."""
    typer.echo("📊 Monthly Report")
    typer.echo("Total tracked: 0h 0m")
    typer.echo("Top project: N/A")
    typer.echo("Productivity trend: N/A")


@app.command()
def comparison(
    period1: str = typer.Argument("last-month", help="First period"),
    period2: str = typer.Argument("this-month", help="Second period")
):
    """Compare productivity between periods."""
    typer.echo(f"📊 Comparison: {period1} vs {period2}")
    typer.echo("Change: No data")


@app.command()
def summary():
    """Quick productivity summary."""
    typer.echo("📈 Productivity Summary:")
    typer.echo("Today: 0h tracked")
    typer.echo("This week: 0h tracked")
    typer.echo("This month: 0h tracked")


@app.command()
def insights():
    """AI insights on productivity."""
    typer.echo("[*] Productivity Insights:")
    typer.echo("- No data available for analysis")
    typer.echo("- Start tracking to see insights")
